﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using Agtrix.MapSuitForms;
using Xamarin.Forms;


namespace Agtrix.Portable.Forms
{
	/// <summary>
	/// This Xamarin.Forms page will actually be rendered natively
	/// on iOS and Android. There is a Heading property that is set
	/// here which will be accessible when rendering natively.
	/// </summary>
	public class ThinkGeoPage : ContentPage
	{
		public String Heading;
	    private Label textViewTitle=new Label();
        private Label txtLastGpsTime = new Label();
        Image imgGps=new Image();
        Image imgGpsOff = new Image();
        Button btnNavigate = new Button(){Text = "Navigate"};
        Button btnSelect = new Button(){Text = "Select n Record"};
        Button btnLayer = new Button(){Text = "Layers"};
        FormsViewMap map = new FormsViewMap();
        Point FixedGPS = new Point() { Y = -28.5046, X = 153.5281 };
        public ThinkGeoPage()
		{
            //return if u want to use map page instead of map renderer for testing
            //return;
            
			Title = "Map";
            imgGps.Source = Device.OnPlatform(iOS: ImageSource.FromFile("Images/gpsgrey.png"),
                Android: ImageSource.FromFile("gpsgrey.png"),
                WinPhone: ImageSource.FromFile("Images/gpsgrey.png"));
            imgGpsOff.Source = Device.OnPlatform(iOS: ImageSource.FromFile("Images/gpsred.png"),
                Android: ImageSource.FromFile("gpsred.png"),
                WinPhone: ImageSource.FromFile("Images/gpsred.png"));
            
            imgGps.BindingContext = this;
            imgGps.SetBinding(Image.IsVisibleProperty, "IsTracking");
            imgGpsOff.BindingContext = this;
            imgGpsOff.SetBinding(Image.IsVisibleProperty, "IsTracking");
			
           map.WidthRequest = Device.OnPlatform(iOS: 400, Android: 400, WinPhone: 500);
           map.HeightRequest = Device.OnPlatform(iOS: 370, Android: 370, WinPhone: 580);
            
            var gridLayout = new Grid
            {
                //VerticalOptions = LayoutOptions.StartAndExpand,
                RowSpacing =Device.OnPlatform(iOS:2,Android:2,WinPhone:30),
                RowDefinitions = 
                {
                    new RowDefinition { Height = GridLength.Auto },
                    new RowDefinition { Height = GridLength.Auto},
                    new RowDefinition { Height = GridLength.Auto},
                    
                },
                ColumnDefinitions = 
                {
                    new ColumnDefinition { Width = GridLength.Auto},
                    new ColumnDefinition { Width = GridLength.Auto},
                    new ColumnDefinition { Width = GridLength.Auto}
                }
            };
            textViewTitle.Text = "GPS Off";
            //imgGpsOff.BindingContext = this;
            //imgGpsOff.SetBinding(Image.IsVisibleProperty, "IsTracking");
            
            btnNavigate.Clicked += btnNavigate_Clicked;
            btnLayer.Clicked+=btnLayer_Clicked;
            btnSelect.Clicked += btnSelect_Clicked;
            var titleLayout = new StackLayout() {Orientation = StackOrientation.Horizontal};
            var buttonsLayout = new StackLayout() { Orientation = StackOrientation.Horizontal };

            titleLayout.Children.Add(imgGps);
            titleLayout.Children.Add(imgGpsOff);
            titleLayout.Children.Add(textViewTitle);
            titleLayout.Children.Add(txtLastGpsTime);

            gridLayout.Children.Add(titleLayout, 0, 3,0,1);
            gridLayout.Children.Add(map, 0,3 , 1, 2);

            buttonsLayout.Children.Add(btnNavigate);
            buttonsLayout.Children.Add(btnSelect);
            buttonsLayout.Children.Add(btnLayer);
            //gridLayout.Children.Add(btnNavigate, 0, 2);
            //gridLayout.Children.Add(btnSelect, 1, 2);
            //gridLayout.Children.Add(btnLayer, 2, 2);

            gridLayout.Children.Add(buttonsLayout, 0, 3,2,3);
            map.SelectionChanged+=map_SelectionChanged;
            Content = new StackLayout()
            {
                Children = { gridLayout }
            };
            
		}

        private async  void btnLayer_Clicked(object sender, EventArgs e)
        {
       
            var action = await DisplayActionSheet ("Layers", null, null, "Bing Photo", "Bing Street");
            //Debug.WriteLine("Action: " + action); // writes the selected button label to the console
            map.NotifyLayerChanged(action);
        }

        private void map_SelectionChanged(object sender, Point e)
        {
            
            //Navigation.PopAsync();
        }

	    
        private bool _isVisible;
        public bool IsTracking
        {
            get
            {
                return this._isVisible;
            }

            private set
            {
                this._isVisible = value;
                this.OnPropertyChanged();
            }
        }

        private ImageSource _GPSImageSource;
        public ImageSource GPSImageSource
        {
            get
            {
                return this._GPSImageSource;
            }

            set
            {
                this._GPSImageSource = value;
                this.OnPropertyChanged();
            }
        }

        private async void btnSelect_Clicked(object sender, EventArgs e)
	    {
            map.IsRecording = !map.IsRecording;
	    }

	    async void btnNavigate_Clicked(object sender, EventArgs e)
        {
            
                try
                {
            IsTracking = !IsTracking;
            map.IsTracking = IsTracking;
            if (IsTracking)
            {
                
                map.NotifyLocationChange(FixedGPS);
                imgGps.IsVisible = true;
                imgGpsOff.IsVisible = false;
                //Device.StartTimer(TimeSpan.FromSeconds(Portable.Forms.App.SessionState.LocationUpdateTime), navigateToCurrentPosition);
                textViewTitle.Text = "GPS On";
             
            }
            else
            {

               
                imgGpsOff.IsVisible = true;
                imgGps.IsVisible = false;
                textViewTitle.Text ="GPS Off";
               // MessagingCenter.Unsubscribe<Location>(this, "LocationString");
              
            }
                }
                catch (Exception ed)
                {

                    throw ed;
                }
           

        }

	    protected override void OnAppearing()
	    {
	        base.OnAppearing();
            
            map.NotifyLocationChange(FixedGPS);

	    }
	}
}
